<?php
require_once ABSPATH . 'wp-content/plugins/cmb2/init.php';

require __DIR__ . '/library/post_types.php';
require __DIR__ . '/library/taxonomies.php';
require __DIR__ . '/library/metaboxes.php';

require __DIR__ . '/library/templates.php';
require __DIR__ . '/library/images.php';
require __DIR__ . '/library/pagebuilder.php';
require __DIR__ . '/library/helpers.php';
require __DIR__ . '/library/ajax.php';

add_action( 'after_setup_theme', function() {
    add_theme_support( 'responsive-embeds' );
    add_theme_support( 'align-wide' );
    add_theme_support( 'wp-block-styles' );
} );

function lula_load_assets() {
	wp_deregister_script( 'jquery' );
    wp_enqueue_script( 'jquery', '//ajax.googleapis.com/ajax/libs/jquery/2.1.0/jquery.min.js', array(), '2.1.0', false );

    wp_enqueue_script('no-js', get_stylesheet_directory_uri() . '/no-js.js', array('jquery'), false, true);
    wp_enqueue_style( 'flickity-css', get_template_directory_uri() . '/dist/flickity.min.css' );
    wp_enqueue_style( 'app', get_template_directory_uri() . '/dist/app.css', [], filemtime(__DIR__.'/dist/app.css') );
    // wp_enqueue_script( 'manifest', get_template_directory_uri() . '/dist/manifest.js', array('jquery'), '1.0.0', true);
    // wp_enqueue_script( 'vendor', get_template_directory_uri() . '/dist/vendor.js', array('manifest'), '1.0.0', true);
    wp_enqueue_script( 'main-app', get_template_directory_uri() . '/dist/app.js', array('jquery'), filemtime(__DIR__.'/dist/app.js') , true);
    wp_enqueue_script( 'main', get_template_directory_uri() . '/assets/javascript/main.js', array('jquery'), '1.0.0', true);
    wp_enqueue_script( 'jquery-mask', get_template_directory_uri() . '/assets/javascript/jquery.mask.min.js', array('jquery'), '1.0.0', true);
    wp_enqueue_script( 'flickity', get_template_directory_uri() . '/dist/flickity.pkgd.min.js', ['jquery'], false, true );
}
add_action( 'wp_enqueue_scripts', 'lula_load_assets' );


function custom_menus() {
    register_nav_menu('main_menu_left',__( 'Menu Principal - Esquerda' ));
    register_nav_menu('main_menu_right',__( 'Menu Principal - Direita' ));
    register_nav_menu('footer_menu',__( 'Menu do Footer' ));
}
add_action( 'init', 'custom_menus' );

function modify_archive_title( $title ) {
    if ( is_category() ) {
        $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
        $title = single_tag_title( '', false );
    } elseif ( is_author() ) {
        $title = '<span class="vcard">' . get_the_author() . '</span>' ;
    }

    return $title;
}

add_filter( 'show_admin_bar', '__return_false' );

add_filter( 'get_the_archive_title', 'modify_archive_title' );

add_filter('excerpt_length', function(){ return 55; }, 999);

function add_myme_types($mime_types){
    $mime_types['svg'] = 'image/svg+xml';
    $mime_types['psd'] = 'image/vnd.adobe.photoshop'; 
    $mime_types['7z'] = 'application/x-7z-compressed'; 
    $mime_types['ai'] = 'application/postscript'; 
    
    return $mime_types;
}
add_filter('upload_mimes', 'add_myme_types', 1, 1);



function set_og_image($currentImage) {
    if (isset($_GET['i'])) {
        $image_url = wp_get_attachment_image_src($_GET['i'], 'full')[0];
        if (isset($image_url)) {
            return $image_url;
        }
    }
    return $currentImage;
}

add_filter('wpseo_opengraph_image', 'set_og_image');
add_filter('wpseo_twitter_image', 'set_og_image');


function fb_change_mce_options( $initArray ) {
    $ext = 'pre[id|name|class|style],iframe[align|longdesc|name|width|height|frameborder|scrolling|marginheight|marginwidth|src]';

    if ( isset( $initArray['extended_valid_elements'] ) ) {
        $initArray['extended_valid_elements'] .= ',' . $ext;
    } else {
        $initArray['extended_valid_elements'] = $ext;
    }
    //$initArray['verify_html'] = false;

    return $initArray;
}
add_filter( 'tiny_mce_before_init', 'fb_change_mce_options' );

function widgets_init() {
    register_sidebar( [
        'name' => __( 'languages_header', 'languages_header' ),
        'id' => 'lang_sidebar',
        'before_title' => '<div class="lang">',
        'after_title' => '</div>',
    ] );
}
add_action( 'widgets_init', 'widgets_init' );

function tabor_setup() {
    // Add support for editor styles.
    add_theme_support( 'editor-styles' );

  // Enqueue editor styles.
  add_editor_style( 'wp-content/themes/LulaLivre-v2/dist/app.css' );
}
add_action( 'after_setup_theme', 'tabor_setup' );

function guest_author_name($name) {
	global $post;
	$author = get_post_meta($post->ID, 'author', true);
	if ($author)
		$name = $author;
	return $name;
}
add_filter('the_author', 'guest_author_name');
add_filter('get_the_author_display_name', 'guest_author_name');


if (!function_exists('pll_e')) {
    function pll_e($str){
        return $str;
    }
}

function the_meta_author(){
    $author = get_post_meta(get_the_ID(), 'author', true);

    echo empty($author) ? 'redação' : $author;
}


function site_by_hacklab($args = []){
    $args += [
        'label' => 'desenvolvido pelo',
        'label_color' => 'black',
        'hacklab_color' => 'black'
    ];
    extract($args);
    ?>
    <!-- <style>
    .site-by-hacklab {
        font-size: 13px;
    }
    .site-by-hacklab span {
        color: <?php echo $label_color ?> !important;
    }
    .site-by-hacklab a{
        font-family: Gothan !important;
        color: <?php echo $hacklab_color ?> !important;
        font-weight: bold;
        font-size: 1.1rem;
    }
    .site-by-hacklab a b {
        color:red !important;
        font-weight: bold;
    }

    </style> -->
    <div class="site-by-hacklab">
        <span><?php echo $label ?></span>
        <a href="https://hacklab.com.br/">hacklab<b>/</b></a>
    </div>
    <?php

}



