<?php

/*
  Widget Name: Mapa de Cadastros
  Description: Adiciona um mapa que exibe os pins dos cadastros
  Author: hacklab/
  Author URI: https://hacklab.com.br/
 */

namespace widgets;

class MapaCadastro extends \SiteOrigin_Widget {

    function __construct() {
        $fields = [
            'title' => [
                'type' => 'text',
                'label' => 'Título',
                'default' => 'Mapa de Comitês Lula Livre'
            ],
            'description' => [
                'type' => 'text',
                'label' => 'Descrição'
            ],
            'button_text' => [
                'type' => 'text',
                'label' => 'Título do Botão',
                'default' => 'Cadastre seu comitê'
            ],
            'button_link' => [
                'type' => 'text',
                'label' => 'Link do Botão',
                'default' => '#mapa-cadastro'
            ],
        ];

        parent::__construct('mapa-cadastro', 'Mapa de Cadastros', [
            'panels_groups' => [WIDGETGROUP_MAIN],
            'description' => 'Adiciona um mapa com pins de cadastro'
                ], [], $fields, plugin_dir_path(__FILE__)
        );
    }

    function get_template_variables($instance, $args)
    {
        $markers = [];

        $markers_query = new \WP_Query([
            'post_type' => 'cadastros',
            'posts_per_page' => '-1',
            'post_status' => 'publish',
            'meta_query' => array(
                'relation' => 'OR',
                array(
                    'key' => 'PESSOA',
                    'value' => 'Comitê'
                ),
                array(
                    'key' => 'PESSOA',
                    'value' => 'Quero organizar um comitê'
                )
            )
        ]);

        while($markers_query->have_posts()){
            $markers_query->the_post();

            $markers[] = [
                'latitude' => get_post_meta(get_the_ID(), 'LATITUDE', true),
                'longitude' => get_post_meta(get_the_ID(), 'LONGITUDE', true),
                'endereco' => get_post_meta(get_the_ID(), 'ENDERECO', true),
                'cidade' => get_post_meta(get_the_ID(), 'CIDADE', true),
                'email' => get_post_meta(get_the_ID(), 'EMAIL', true),
            ];
        }

        wp_localize_script('no-js', 'mapa_cadastro', $markers );

        return [];
    }

    function get_template_name($instance) {
        return 'template';
    }

    function get_style_name($instance) {
        return 'style';
    }

}

Siteorigin_widget_register('mapa-cadastro', __FILE__, 'widgets\MapaCadastro');
